from setuptools import setup
setup(
    name = "fc_penwei250",
    version = "1.0",
    py_modules = ["fc_dc_bigdata"],
    author = "大数据",
    author_email = "fc@bigdata.com",
    description = "大数据2"
)